==> UndernetCS-0.8.6.tar.bz2: UndernetCS-0.8.6/src/UndernetCS_NewsChecker.tcl <==
###############################################################################
#                 Undernet Channel Service Management Script                  #
###############################################################################
# (c) 2001-2008 Yann RICHARD alias Ze <ze(arobase)nbox.org>                   #
###############################################################################

###############################################################################
# This program is distributed under the GNU General Public Licence v3         #
# See the LICENCE file for more information.                                  #
###############################################################################
#   This file is part of UndernetCS.                                          #
#                                                                             #
#   UndernetCS is free software: you can redistribute it and/or modify        #
#   it under the terms of the GNU General Public License as published by      #
#   the Free Software Foundation, either version 3 of the License, or         #
#   (at your option) any later version.                                       #
#                                                                             #
#   UndernetCS is distributed in the hope that it will be useful,             #
#   but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#   GNU General Public License for more details.                              #
#                                                                             #
#   You should have received a copy of the GNU General Public License         #
#   along with UndernetCS.  If not, see <http://www.gnu.org/licenses/>.       #
###############################################################################
set UndernetCS_NotifyOwner 1

# Checking for new every day at 04h00.
bind time - "* 04 * * *" UndernetCS:NewChecker:CheckForNews
proc UndernetCS:NewChecker:CheckForNews {min hour day month year} {
    global Undernet_NotifyOwner

    # Before doing something verify if user want this
    if { ![UndernetCS:NewChecker:IsNewsCheckActive] } {
	return 0
    }
    if {[info commands sendnote] == ""} {
	UndernetCS:PutLog "UndernetCS need notes module." "NEWS" 2
	return 0
    }
    if {[catch {package require http}]} {
	UndernetCS:PutLog "UndernetCS need http package." "NEWS" 2
	return 0
    }
    if {[catch {::http::geturl http://undernetcs.nbox.org/undernetcs.txt} update]} {
	UndernetCS:PutLog "Cannot connect to update server." "NEWS" 2
	return 0
    }
    set line [::http::data $update]
    unset update
    set line [split $line]
    set cmd [lindex $line 0]
    UndernetCS:PutLog "Checking for news ; Receiving $line" "NEWS" 5
    if { $cmd == "update" } {
	UndernetCS:NewChecker:Update [lrange $line 1 end]
	return 1
    }
    # NOT USED #
    if { $cmd == "announce" } {
	UndernetCS:NewChecker:Announce [lrange $line 1 end]
	return 1
    }
    return 0
}

# NOT USED #
proc UndernetCS:NewChecker:IsNewsCheckActive {} {
    global UndernetCS_UseNewsChecker
    return $UndernetCS_UseNewsChecker
}

proc UndernetCS:NewChecker:WantUpdate {} {
    return 1
}

proc UndernetCS:NewChecker:Update {arg} {
    global UndernetCS_NumVersion owner
    # Verify if user want announce
    UndernetCS:PutLog "Checking if there is a new release.($arg)" "NEWS" 5
    if { [UndernetCS:NewChecker:WantUpdate] } {
	if { [lindex $arg 0] > $UndernetCS_NumVersion } {
	    UndernetCS:NewChecker:SendNote "$owner" "[lrange $arg 1 end]"
	}
    }
}

# NOT USED FOR THE MOMMENT #
proc UndernetCS:NewChecker:Announce {news} {
    global owner
    # Verify if user want announce
    if { [UndernetCS:NewChecker:WantAnnounce] } {
	UndernetCS:NewChecker:SendNote "$owner" "$news"
    }
}

proc UndernetCS:NewChecker:SendNote {dest msg} {
    UndernetCS:PutLog "Sending note to perm owner ($dest with $msg)" "NEWS" 5
    foreach user $dest {
	sendnote "UndernetCS" "$user" "$msg"
    }
}


### EOF ###

==> UndernetCS-1.0.0.tar.bz2: UndernetCS-1.0.0/src/UndernetCS_NewsChecker.tcl <==
###############################################################################
#                 Undernet Channel Service Management Script                  #
###############################################################################
# (c) 2001-2009 Yann RICHARD alias Ze <ze(arobase)nbox.org>                   #
###############################################################################

###############################################################################
# This program is distributed under the GNU General Public Licence v3         #
# See the LICENCE file for more information.                                  #
###############################################################################
#   This file is part of UndernetCS.                                          #
#                                                                             #
#   This program is free software: you can redistribute it and/or modify      #
#   it under the terms of the GNU Affero General Public License as            #
#   published by the Free Software Foundation, either version 3 of the        #
#   License, or (at your option) any later version.                           #
#                                                                             #
#   This program is distributed in the hope that it will be useful,           #
#   but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#   GNU Affero General Public License for more details.                       #
#                                                                             #
#   You should have received a copy of the GNU Affero General Public License  #
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.     #
#                                                                             #
###############################################################################
set UndernetCS_NotifyOwner 1

# Checking for new every day at 04h00.
bind time - "00 04 * * *" UndernetCS:NewChecker:CheckForNews
proc UndernetCS:NewChecker:CheckForNews {min hour day month year} {
    global Undernet_NotifyOwner

    # Before doing something verify if user want this
    if { ![UndernetCS:NewChecker:IsNewsCheckActive] } {
	return 0
    }
    if {[info commands sendnote] == ""} {
	UndernetCS:PutLog "UndernetCS need notes module." "NEWS" 2
	return 0
    }
    if {[catch {package require http}]} {
	UndernetCS:PutLog "UndernetCS need http package." "NEWS" 2
	return 0
    }
    if {[catch {::http::geturl http://undernetcs.nbox.org/undernetcs.txt} update]} {
	UndernetCS:PutLog "Cannot connect to update server." "NEWS" 2
	return 0
    }
    set line [::http::data $update]
    unset update
    set line [split $line]
    set cmd [lindex $line 0]
    UndernetCS:PutLog "Checking for news ; Receiving $line" "NEWS" 5
    if { $cmd == "update" } {
	UndernetCS:NewChecker:Update [lrange $line 1 end]
	return 1
    }
    # NOT USED #
    if { $cmd == "announce" } {
	UndernetCS:NewChecker:Announce [lrange $line 1 end]
	return 1
    }
    return 0
}

# NOT USED #
proc UndernetCS:NewChecker:IsNewsCheckActive {} {
    global UndernetCS_UseNewsChecker
    return $UndernetCS_UseNewsChecker
}

proc UndernetCS:NewChecker:WantUpdate {} {
    return 1
}

proc UndernetCS:NewChecker:Update {arg} {
    global UndernetCS_NumVersion owner
    # Verify if user want announce
    UndernetCS:PutLog "Checking if there is a new release.($arg)" "NEWS" 5
    if { [UndernetCS:NewChecker:WantUpdate] } {
	if { [lindex $arg 0] > $UndernetCS_NumVersion } {
	    UndernetCS:NewChecker:SendNote "$owner" "[lrange $arg 1 end]"
	}
    }
}

# NOT USED FOR THE MOMMENT #
proc UndernetCS:NewChecker:Announce {news} {
    global owner
    # Verify if user want announce
    if { [UndernetCS:NewChecker:WantAnnounce] } {
	UndernetCS:NewChecker:SendNote "$owner" "$news"
    }
}

proc UndernetCS:NewChecker:SendNote {dest msg} {
    UndernetCS:PutLog "Sending note to perm owner ($dest with $msg)" "NEWS" 5
    foreach user $dest {
	sendnote "UndernetCS" "$user" "$msg"
    }
}


### EOF ###
